@@ -1,4 +1,3 @@
-pub use crate::app_entry;
 pub use crate::capability::create_cap_claim;
 pub use crate::capability::create_cap_grant;
 pub use crate::capability::delete_cap_grant;
@@ -50,13 +49,11 @@ pub use crate::link::get_links;
 pub use crate::link::HdkLinkType;
 pub use crate::map_extern;
 pub use crate::map_extern::ExternResult;
-pub use crate::map_extern_infallible;
 pub use crate::p2p::call;
 pub use crate::p2p::call_remote;
 pub use crate::p2p::emit_signal;
 pub use crate::p2p::remote_signal;
 pub use crate::random::*;
-pub use crate::register_entry;
 pub use crate::time::schedule;
 pub use crate::time::sleep;
 pub use crate::time::sys_time;
@@ -71,12 +68,18 @@ pub use hdk_derive::hdk_extern;
 pub use holo_hash;
 pub use holo_hash::AgentPubKey;
 pub use holo_hash::AnyDhtHash;
+pub use holo_hash::AnyLinkableHash;
 pub use holo_hash::EntryHash;
 pub use holo_hash::EntryHashes;
+pub use holo_hash::ExternalHash;
 pub use holo_hash::HasHash;
 pub use holo_hash::HeaderHash;
 pub use holo_hash::HoloHash;
 pub use holo_hash::HoloHashed;
+pub use holochain_deterministic_integrity;
+pub use holochain_deterministic_integrity::map_extern_infallible;
+pub use holochain_deterministic_integrity::prelude::app_entry;
+pub use holochain_deterministic_integrity::prelude::register_entry;
 pub use holochain_wasmer_guest::*;
 pub use holochain_zome_types;
 pub use holochain_zome_types::prelude::*;
@@ -89,6 +92,9 @@ pub use tracing::{debug, error, info, instrument, trace, warn};
 #[cfg(feature = "mock")]
 pub use mockall;
 
+#[cfg(feature = "mock")]
+pub use crate::hdk::MockHdkT;
+
 // This needs to be called at least once _somewhere_ and is idempotent.
 #[macro_export]
 macro_rules! holochain_externs {
